@@ -41,8 +41,8 @@ class Resources : public Module {
     Q_CLASSINFO("D-Bus Interface", "org.kde.ActivityManager.Resources")
 
 public:
-    Resources(QObject *parent = Q_NULLPTR);
-    virtual ~Resources();
+    explicit Resources(QObject *parent = nullptr);
+    ~Resources() override;
 
 public Q_SLOTS:
     /**
